@@ -118,7 +118,11 @@ void my_log_callback(struct mosquitto *mosq, void *obj, int level, const char *s
 
 void print_usage(void)
 {
-	printf("mosquitto_sub is a simple mqtt client that will subscribe to a single topic and print all messages it receives.\n\n");
+	int major, minor, revision;
+
+	mosquitto_lib_version(&major, &minor, &revision);
+	printf("mosquitto_sub is a simple mqtt client that will subscribe to a single topic and print all messages it receives.\n");
+	printf("mosquitto_sub version %s running on libmosquitto %d.%d.%d.\n\n", VERSION, major, minor, revision);
 	printf("Usage: mosquitto_sub [-c] [-h host] [-k keepalive] [-p port] [-q qos] [-v] -t topic ...\n");
 	printf("                     [-i id] [-I id_prefix]\n");
 	printf("                     [-d] [--quiet]\n");
@@ -474,7 +478,10 @@ int main(int argc, char *argv[])
 			return 1;
 		}
 		snprintf(id, len, "mosqsub/%d-%s", getpid(), hostname);
-		id[MOSQ_MQTT_ID_MAX_LENGTH] = '\0';
+		if(strlen(id) > MOSQ_MQTT_ID_MAX_LENGTH){
+			/* Enforce maximum client id length of 23 characters */
+			id[MOSQ_MQTT_ID_MAX_LENGTH] = '\0';
+		}
 	}
 
 	mosq = mosquitto_new(id, clean_session, &ud);
@@ -537,9 +544,7 @@ int main(int argc, char *argv[])
 		mosquitto_lib_cleanup();
 	}
 
-	do{
-		rc = mosquitto_loop(mosq, -1, 100);
-	}while(rc == MOSQ_ERR_SUCCESS);
+	rc = mosquitto_loop_forever(mosq, -1, 1);
 
 	mosquitto_destroy(mosq);
 	mosquitto_lib_cleanup();
