@@ -37,4 +37,8 @@ int _mosquitto_fix_sub_topic(char **subtopic);
 uint16_t _mosquitto_mid_generate(struct mosquitto *mosq);
 int _mosquitto_topic_wildcard_len_check(const char *str);
 
+#if defined(WITH_TLS) && defined(WITH_TLS_PSK)
+int _mosquitto_hex2bin(const char *hex, unsigned char *bin, int bin_max_len);
+#endif
+
 #endif
