@@ -37,7 +37,7 @@ POSSIBILITY OF SUCH DAMAGE.
 #include <send_mosq.h>
 #include <util_mosq.h>
 
-int mqtt3_handle_connack(mosquitto_db *db, struct mosquitto *context)
+int mqtt3_handle_connack(struct mosquitto_db *db, struct mosquitto *context)
 {
 	uint8_t byte;
 	uint8_t rc;
