@@ -29,11 +29,10 @@ try:
     sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     sock.connect(("localhost", 1888))
     sock.send(connect_packet)
-    connack_recvd = sock.recv(len(connack_packet))
-    sock.close()
-
-    if mosq_test.packet_matches("connack", connack_recvd, connack_packet):
+    if mosq_test.expect_packet(sock, "connack", connack_packet):
         rc = 0
+
+    sock.close()
 finally:
     broker.terminate()
     broker.wait()
