@@ -32,13 +32,11 @@ try:
     sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     sock.connect(("localhost", 1888))
     sock.send(connect_packet)
-    connack_recvd = sock.recv(len(connack_packet))
 
-    if mosq_test.packet_matches("connack", connack_recvd, connack_packet):
+    if mosq_test.expect_packet(sock, "connack", connack_packet):
         sock.send(unsubscribe_packet)
-        unsuback_recvd = sock.recv(len(unsuback_packet))
 
-        if mosq_test.packet_matches("unsuback", unsuback_recvd, unsuback_packet):
+        if mosq_test.expect_packet(sock, "unsuback", unsuback_packet):
             rc = 0
 
     sock.close()
