@@ -37,20 +37,15 @@ try:
     sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     sock.connect(("localhost", 1888))
     sock.send(connect_packet)
-    connack_recvd = sock.recv(len(connack_packet))
 
-    if mosq_test.packet_matches("connack", connack_recvd, connack_packet):
+    if mosq_test.expect_packet(sock, "connack", connack_packet):
         sock.send(publish_packet)
-        puback_recvd = sock.recv(len(puback_packet))
 
-        if mosq_test.packet_matches("puback", puback_recvd, puback_packet):
+        if mosq_test.expect_packet(sock, "puback", puback_packet):
             sock.send(subscribe_packet)
-            suback_recvd = sock.recv(len(suback_packet))
 
-            if mosq_test.packet_matches("suback", suback_recvd, suback_packet):
-                publish_recvd = sock.recv(len(publish0_packet))
-
-                if mosq_test.packet_matches("publish0", publish_recvd, publish0_packet):
+            if mosq_test.expect_packet(sock, "suback", suback_packet):
+                if mosq_test.expect_packet(sock, "publish0", publish0_packet):
                     rc = 0
     sock.close()
 finally:
