@@ -26,13 +26,11 @@ puback_packet = mosq_test.gen_puback(mid)
 sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 sock.connect(("localhost", 1888))
 sock.send(connect_packet)
-connack_recvd = sock.recv(len(connack_packet))
 
-if mosq_test.packet_matches("connack", connack_recvd, connack_packet):
+if mosq_test.expect_packet(sock, "connack", connack_packet):
     sock.send(publish_packet)
-    puback_recvd = sock.recv(len(puback_packet))
 
-    if mosq_test.packet_matches("puback", puback_recvd, puback_packet):
+    if mosq_test.expect_packet(sock, "puback", puback_packet):
         rc = 0
 
 sock.close()
