@@ -22,9 +22,8 @@ connack_packet = mosq_test.gen_connack(rc=0)
 sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 sock.connect(("localhost", 1888))
 sock.send(connect_packet)
-connack_recvd = sock.recv(len(connack_packet))
 
-if mosq_test.packet_matches("connack", connack_recvd, connack_packet):
+if mosq_test.expect_packet(sock, "connack", connack_packet):
     rc = 0
 
 sock.close()
