@@ -56,17 +56,14 @@ client = subprocess.Popen(client_args, env=env)
 try:
     (conn, address) = sock.accept()
     conn.settimeout(10)
-    connect_recvd = conn.recv(len(connect_packet))
 
-    if mosq_test.packet_matches("connect", connect_recvd, connect_packet):
+    if mosq_test.expect_packet(conn, "connect", connect_packet):
         conn.send(connack_packet)
-        subscribe_recvd = conn.recv(len(subscribe_packet))
 
-        if mosq_test.packet_matches("subscribe", subscribe_recvd, subscribe_packet):
+        if mosq_test.expect_packet(conn, "subscribe", subscribe_packet):
             conn.send(suback_packet)
-            disconnect_recvd = conn.recv(len(disconnect_packet))
         
-            if mosq_test.packet_matches("disconnect", disconnect_recvd, disconnect_packet):
+            if mosq_test.expect_packet(conn, "disconnect", disconnect_packet):
                 rc = 0
         
     conn.close()
